/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.maven.plugins.as.control.mojo;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.jboss.maven.plugins.as.common.JbossAsRuntimeDelegate;

/**
 * JbossAsControlStartMojo
 * 
 * Maven2 Plugin to start the AS
 * 
 * @author <a href="mailto:andrew.rubinger@jboss.org">ALR</a>
 * @version $Revision: $
 * @phase pre-integration-test
 * @goal start
 */
public class JbossAsControlStartMojo extends JbossAsControlAbstractMojo
{
   // Class Members

   private static final Log logger = LogFactory.getLog(JbossAsControlStartMojo.class);

   // Maven Configuration Properties

   /**
    * Whether or not to run the integration tests
    * 
    * @parameter alias="jboss.test.run" default-value=false expression="${jboss.test.run}"
    */
   private boolean runTests;

   /**
    * JVM Args to be used in starting the AS
    * 
    * @parameter
    */
   private List<String> jvmArgs = new ArrayList<String>();

   /**
    * Server configuration to use
    * 
    * @parameter expression="${jboss.serverConfigName}"
    * @required
    */
   private String serverConfigName;

   /**
    * Delegate for JBossAS Runtime Operations
    */
   private final JbossAsRuntimeDelegate delegate = new JbossAsRuntimeDelegate();

   // Functional Methods
   /**
    * Maven Plugin Execution Entry
    * 
    * Starts the Server
    */
   public void execute() throws MojoExecutionException, MojoFailureException
   {
      // If we're skipping the tests, return
      if (!this.isEnabled())
      {
         JbossAsControlStartMojo.logger.info("Skipping JBossAS Start, to enable set \"jboss.test.run\".");
         return;
      }

      // Start the Server
      try
      {
         delegate.startJbossAs(this.getServerConfigName(), this.getJvmArgs());
      }
      catch (IOException ioe)
      {
         throw new MojoExecutionException("Could not start JBossAS", ioe);
      }
   }

   // Accessors / Mutators

   public boolean isEnabled()
   {
      return this.runTests;
   }

   public List<String> getJvmArgs()
   {
      return jvmArgs;
   }

   public void setJvmArgs(List<String> jvmArgs)
   {
      this.jvmArgs = jvmArgs;
   }

   public String getServerConfigName()
   {
      return serverConfigName;
   }

   public void setServerConfigName(String serverConfigName)
   {
      this.serverConfigName = serverConfigName;
   }
}
