/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.maven.plugins.as.control.mojo;

import java.io.File;
import java.util.Set;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;
import org.jboss.jbossas.servermanager.Server;
import org.jboss.jbossas.servermanager.ServerManager;

/**
 * JbossAsControlUndeployMojo.java
 * 
 * Maven2 Plugin to undeploy from a running AS instance
 * 
 * @author <a href="mailto:guillaumeradde@hotmail.com">Guillaume Radde</a>
 * @version $Revision: $
 * @phase post-integration-test
 * @goal undeploy
 */
public class JbossAsControlUndeployMojo extends JbossAsControlAbstractDeploymentMojo {

    /**
     * Maven Plugin Execution Entry
     * 
     * Undeployes the file(s)
     */
    public void execute() throws MojoExecutionException, MojoFailureException {
        // If we're skipping the tests, return
        if (!this.isEnabled()) {
            logger.info("Skipping the undeployment to JBossAS, to enable set \"jboss.test.run\".");
            return;
        }

        // Obtain ServerManager
        ServerManager manager = this.delegate.getServerManager();

        // Obtain server name
        String name = this.getServerConfigName();

        // Get Server
        Server server = manager.getServer(name);

        // Ensure Server found
        if (server == null) {
            throw new MojoExecutionException("Could not undeploy from the specified server \"" + name + "\": was not found running");
        }

        // Get all configured deployables
        Set<File> deployables = this.getDeployableUnits();

        // Get the old CL
        ClassLoader oldLoader = Thread.currentThread().getContextClassLoader();

        // Set a CL which has stuff from jbossall-client
        ClassLoader newLoader = this.getJbossClientClassLoader(oldLoader);
        Thread.currentThread().setContextClassLoader(newLoader);
        try
      {
         for (File file : deployables)
         {
            try
            {
               server.undeploy(file);
               logger.info("Undeployed " + file.toString() + " from JBossAS instance \"" + name + "\"");
            }
            catch (Exception e)
            {
               throw new MojoExecutionException("Could not undeploy " + file.toString(), e);
            }
         }
      }
      finally
      {
         Thread.currentThread().setContextClassLoader(oldLoader);
      }
    }

}
